##  Insights from Platform Fact Sheet
  * Understand which applications belong to a digital platform by using the application landscape report.
  * Understand which platforms contain which applications and which business capabilities they support by leveraging the matrix report.
  * Understand which IT components belong to a technical platform by using the application landscape report.
